package com.ss.android.socialbase.downloader.downloader;

import android.os.SystemClock;
import com.ss.android.socialbase.downloader.common.AppStatusManager;
import com.ss.android.socialbase.downloader.constants.DownloadConstants;
import com.ss.android.socialbase.downloader.constants.DownloadErrorCode;
import com.ss.android.socialbase.downloader.db.SqlDownloadCache;
import com.ss.android.socialbase.downloader.exception.BaseException;
import com.ss.android.socialbase.downloader.exception.DownloadOnlyWifiException;
import com.ss.android.socialbase.downloader.exception.DownloadPauseReserveWifiException;
import com.ss.android.socialbase.downloader.exception.DownloadRetryNeedlessException;
import com.ss.android.socialbase.downloader.impls.DefaultDownloadCache;
import com.ss.android.socialbase.downloader.impls.DownloadCache;
import com.ss.android.socialbase.downloader.impls.DownloadProxy;
import com.ss.android.socialbase.downloader.logger.Logger;
import com.ss.android.socialbase.downloader.model.DownloadChunk;
import com.ss.android.socialbase.downloader.model.DownloadInfo;
import com.ss.android.socialbase.downloader.model.RandomAccessOutputStream;
import com.ss.android.socialbase.downloader.monitor.DownloadMonitorHelper;
import com.ss.android.socialbase.downloader.network.AbsDownloadHttpConnection;
import com.ss.android.socialbase.downloader.network.IDownloadHttpConnection;
import com.ss.android.socialbase.downloader.reader.AsyncStreamReader;
import com.ss.android.socialbase.downloader.reader.IStreamReader;
import com.ss.android.socialbase.downloader.reader.SyncStreamReader;
import com.ss.android.socialbase.downloader.segment.Buffer;
import com.ss.android.socialbase.downloader.setting.DownloadSetting;
import com.ss.android.socialbase.downloader.setting.DownloadSettingKeys;
import com.ss.android.socialbase.downloader.thread.IDownloadRunnableCallback;
import com.ss.android.socialbase.downloader.utils.DownloadExpSwitchCode;
import com.ss.android.socialbase.downloader.utils.DownloadUtils;
import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.util.concurrent.ExecutorService;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class DownloadResponseHandler {
    public static final boolean DEBUG = false;
    public static final int MIN_SYNC_STEP_BYTE = 65536;
    public static final long MIN_SYNC_TIME_MS = 500;
    public static String TAG = "ResponseHandler";
    public final AppStatusManager appStatusManager;
    public final boolean bugfixCancelThenUpdate;
    public final IDownloadRunnableCallback callback;
    public volatile boolean canceled;
    public long curOffset;
    public IDownloadCache customCache;
    public long debugReadTimeNs;
    public long debugSyncTimeNs;
    public long debugTotalTimeNs;
    public long debugWriteTimeNs;
    public DownloadCache downloadCache;
    public final DownloadChunk downloadChunk;
    public volatile long downloadChunkContentLen;
    public final DownloadInfo downloadInfo;
    public volatile long endOffset;
    public BaseException exception;
    public long handleStartOffset;
    public final boolean hasSyncStrategy;
    public final IDownloadHttpConnection httpConnection;
    public final boolean isMonitorRw;
    public RandomAccessOutputStream outputStream;
    public volatile boolean paused;
    public boolean rwConcurrent;
    public final DownloadSetting setting;
    public ISqlDownloadCache sqlDownloadCache;
    public final long syncIntervalMsBg;
    public final long syncIntervalMsFg;
    public final String url;
    public boolean openLimitSpeed = false;
    public volatile long lastSyncBytes = 0;
    public volatile long lastSyncTimestamp = 0;

    public DownloadResponseHandler(DownloadInfo downloadInfo, String str, IDownloadHttpConnection iDownloadHttpConnection, DownloadChunk downloadChunk, IDownloadRunnableCallback iDownloadRunnableCallback) {
        this.downloadInfo = downloadInfo;
        this.url = str;
        IDownloadCache downloadCache = DownloadComponentManager.getDownloadCache();
        this.customCache = downloadCache;
        if (downloadCache instanceof DefaultDownloadCache) {
            DefaultDownloadCache defaultDownloadCache = (DefaultDownloadCache) downloadCache;
            this.downloadCache = defaultDownloadCache.getDownloadCache();
            this.sqlDownloadCache = defaultDownloadCache.getSqlDownloadCache();
        }
        this.httpConnection = iDownloadHttpConnection;
        this.downloadChunk = downloadChunk;
        this.callback = iDownloadRunnableCallback;
        long currentOffset = downloadChunk.getCurrentOffset();
        this.curOffset = currentOffset;
        this.handleStartOffset = currentOffset;
        if (downloadChunk.isHostChunk()) {
            this.downloadChunkContentLen = downloadChunk.getContentLength();
        } else {
            this.downloadChunkContentLen = downloadChunk.getRetainLength(false);
        }
        this.endOffset = downloadChunk.getEndOffset();
        this.appStatusManager = AppStatusManager.getInstance();
        DownloadSetting obtain = DownloadSetting.obtain(downloadInfo.getId());
        this.setting = obtain;
        boolean z = obtain.optInt(DownloadSettingKeys.SYNC_STRATEGY, 0) == 1;
        this.hasSyncStrategy = z;
        if (z) {
            this.syncIntervalMsFg = Math.max(this.setting.optInt(DownloadSettingKeys.SYNC_INTERVAL_MS_FG, 5000), 500L);
            this.syncIntervalMsBg = Math.max(this.setting.optInt(DownloadSettingKeys.SYNC_INTERVAL_MS_BG, 1000), 500L);
        } else {
            this.syncIntervalMsFg = 0L;
            this.syncIntervalMsBg = 0L;
        }
        this.isMonitorRw = this.setting.optInt(DownloadSettingKeys.MONITOR_RW) == 1;
        this.bugfixCancelThenUpdate = DownloadExpSwitchCode.isSwitchEnable(65536);
    }

    private boolean canReuseConnection() {
        return this.downloadInfo.isNeedReuseFirstConnection() && this.downloadChunk.isReuseingFirstConnection();
    }

    private void cancelConnection() {
        ExecutorService cPUThreadExecutor;
        if (this.httpConnection == null || (cPUThreadExecutor = DownloadComponentManager.getCPUThreadExecutor()) == null) {
            return;
        }
        cPUThreadExecutor.execute(new Runnable() { // from class: com.ss.android.socialbase.downloader.downloader.DownloadResponseHandler.1
            @Override // java.lang.Runnable
            public void run() {
                try {
                    DownloadResponseHandler.this.httpConnection.end();
                } catch (Throwable unused) {
                }
            }
        });
    }

    private void checkAndSync(boolean z) {
        long uptimeMillis = SystemClock.uptimeMillis();
        long j2 = uptimeMillis - this.lastSyncTimestamp;
        if (this.hasSyncStrategy) {
            if (j2 > (this.appStatusManager.isAppForeground() ? this.syncIntervalMsFg : this.syncIntervalMsBg)) {
                sync();
                this.lastSyncTimestamp = uptimeMillis;
                return;
            }
            return;
        }
        long j3 = this.curOffset - this.lastSyncBytes;
        if (z || isNeedSync(j3, j2)) {
            sync();
            this.lastSyncTimestamp = uptimeMillis;
        }
    }

    private IStreamReader createStreamReader(InputStream inputStream) {
        int writeBufferSize = DownloadComponentManager.getWriteBufferSize();
        if (this.setting.optInt("rw_concurrent", 0) == 1 && this.downloadInfo.getChunkCount() == 1 && this.downloadInfo.getTotalBytes() > 20971520) {
            try {
                AsyncStreamReader asyncStreamReader = new AsyncStreamReader(inputStream, writeBufferSize, this.setting.optInt(DownloadSettingKeys.RW_CONCURRENT_MAX_BUFFER_COUNT, 4));
                this.rwConcurrent = true;
                return asyncStreamReader;
            } catch (Throwable th) {
                th.printStackTrace();
            }
        }
        SyncStreamReader syncStreamReader = new SyncStreamReader(inputStream, writeBufferSize);
        this.rwConcurrent = false;
        return syncStreamReader;
    }

    private boolean isNeedSync(long j2, long j3) {
        return j2 > 65536 && j3 > 500;
    }

    private boolean isStoppedStatus() {
        return this.paused || this.canceled;
    }

    private void sync() {
        boolean z;
        long nanoTime = this.isMonitorRw ? System.nanoTime() : 0L;
        try {
            this.outputStream.flushAndSync();
            z = true;
        } catch (Exception unused) {
            z = false;
        }
        if (z) {
            this.downloadInfo.updateRealDownloadTime(true);
            boolean z2 = this.downloadInfo.getChunkCount() > 1;
            IDownloadProxy iDownloadProxy = DownloadProxy.get(DownloadUtils.needNotifyDownloaderProcess());
            if (z2) {
                updateDownloadChunk(this.sqlDownloadCache);
                if (iDownloadProxy != null) {
                    iDownloadProxy.updateDownloadInfo(this.downloadInfo);
                } else {
                    this.sqlDownloadCache.OnDownloadTaskProgress(this.downloadInfo.getId(), this.downloadInfo.getCurBytes());
                }
            } else if (iDownloadProxy != null) {
                iDownloadProxy.updateDownloadInfo(this.downloadInfo);
            } else {
                this.sqlDownloadCache.OnDownloadTaskProgress(this.downloadChunk.getId(), this.curOffset);
            }
            this.lastSyncBytes = this.curOffset;
        }
        if (this.isMonitorRw) {
            this.debugSyncTimeNs += System.nanoTime() - nanoTime;
        }
    }

    private void updateDownloadChunk(IDownloadCache iDownloadCache) {
        DownloadChunk downloadChunk;
        DownloadChunk downloadChunk2;
        if (iDownloadCache == null) {
            return;
        }
        IDownloadProxy iDownloadProxy = null;
        boolean z = iDownloadCache instanceof SqlDownloadCache;
        if (z && (iDownloadProxy = DownloadProxy.get(DownloadUtils.needNotifyDownloaderProcess())) == null) {
            return;
        }
        IDownloadProxy iDownloadProxy2 = iDownloadProxy;
        if (this.downloadChunk.isHostChunk()) {
            downloadChunk = this.downloadChunk.getFirstReuseChunk();
        } else {
            downloadChunk = this.downloadChunk;
        }
        DownloadChunk downloadChunk3 = downloadChunk;
        if (downloadChunk3 != null) {
            downloadChunk3.setCurrentOffset(this.curOffset);
            if (z && iDownloadProxy2 != null) {
                iDownloadProxy2.updateSubDownloadChunk(downloadChunk3.getId(), downloadChunk3.getChunkIndex(), downloadChunk3.getHostChunkIndex(), this.curOffset);
                downloadChunk2 = downloadChunk3;
            } else {
                downloadChunk2 = downloadChunk3;
                iDownloadCache.updateSubDownloadChunk(downloadChunk3.getId(), downloadChunk3.getChunkIndex(), downloadChunk3.getHostChunkIndex(), this.curOffset);
            }
            if (downloadChunk2.canRefreshCurOffsetForReuseChunk()) {
                boolean z2 = false;
                if (downloadChunk2.hasNoBytesDownload()) {
                    long nextChunkCurOffset = downloadChunk2.getNextChunkCurOffset();
                    if (nextChunkCurOffset > this.curOffset) {
                        if (z && iDownloadProxy2 != null) {
                            iDownloadProxy2.updateDownloadChunk(downloadChunk2.getId(), downloadChunk2.getHostChunkIndex(), nextChunkCurOffset);
                        } else {
                            iDownloadCache.updateDownloadChunk(downloadChunk2.getId(), downloadChunk2.getHostChunkIndex(), nextChunkCurOffset);
                        }
                        z2 = true;
                    }
                }
                if (z2) {
                    return;
                }
                if (z && iDownloadProxy2 != null) {
                    iDownloadProxy2.updateDownloadChunk(downloadChunk2.getId(), downloadChunk2.getHostChunkIndex(), this.curOffset);
                } else {
                    iDownloadCache.updateDownloadChunk(downloadChunk2.getId(), downloadChunk2.getHostChunkIndex(), this.curOffset);
                }
            }
        } else if (this.downloadChunk.isHostChunk()) {
            if (z && iDownloadProxy2 != null) {
                iDownloadProxy2.updateDownloadChunk(this.downloadChunk.getId(), this.downloadChunk.getChunkIndex(), this.curOffset);
            } else {
                iDownloadCache.updateDownloadChunk(this.downloadChunk.getId(), this.downloadChunk.getChunkIndex(), this.curOffset);
            }
        }
    }

    public void cancel() {
        if (this.canceled) {
            return;
        }
        synchronized (this.callback) {
            this.canceled = true;
        }
        cancelConnection();
    }

    public long getCurOffset() {
        return this.curOffset;
    }

    public long getLastSyncBytes() {
        return this.lastSyncBytes;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:177:0x02e5 A[Catch: all -> 0x04df, TRY_ENTER, TryCatch #29 {all -> 0x04df, blocks: (B:177:0x02e5, B:178:0x02ec, B:207:0x0365, B:209:0x036b, B:210:0x036e, B:251:0x045a, B:252:0x045c, B:256:0x0463, B:258:0x0483, B:286:0x04d3, B:288:0x04d9, B:289:0x04dc, B:290:0x04de), top: B:338:0x002b, inners: #22 }] */
    /* JADX WARN: Removed duplicated region for block: B:180:0x0308  */
    /* JADX WARN: Removed duplicated region for block: B:207:0x0365 A[Catch: all -> 0x04df, TRY_ENTER, TryCatch #29 {all -> 0x04df, blocks: (B:177:0x02e5, B:178:0x02ec, B:207:0x0365, B:209:0x036b, B:210:0x036e, B:251:0x045a, B:252:0x045c, B:256:0x0463, B:258:0x0483, B:286:0x04d3, B:288:0x04d9, B:289:0x04dc, B:290:0x04de), top: B:338:0x002b, inners: #22 }] */
    /* JADX WARN: Removed duplicated region for block: B:236:0x03ec A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:237:0x03ed  */
    /* JADX WARN: Removed duplicated region for block: B:258:0x0483 A[Catch: all -> 0x04df, TRY_LEAVE, TryCatch #29 {all -> 0x04df, blocks: (B:177:0x02e5, B:178:0x02ec, B:207:0x0365, B:209:0x036b, B:210:0x036e, B:251:0x045a, B:252:0x045c, B:256:0x0463, B:258:0x0483, B:286:0x04d3, B:288:0x04d9, B:289:0x04dc, B:290:0x04de), top: B:338:0x002b, inners: #22 }] */
    /* JADX WARN: Removed duplicated region for block: B:288:0x04d9 A[Catch: all -> 0x04df, TryCatch #29 {all -> 0x04df, blocks: (B:177:0x02e5, B:178:0x02ec, B:207:0x0365, B:209:0x036b, B:210:0x036e, B:251:0x045a, B:252:0x045c, B:256:0x0463, B:258:0x0483, B:286:0x04d3, B:288:0x04d9, B:289:0x04dc, B:290:0x04de), top: B:338:0x002b, inners: #22 }] */
    /* JADX WARN: Type inference failed for: r6v0, types: [long] */
    /* JADX WARN: Type inference failed for: r6v1 */
    /* JADX WARN: Type inference failed for: r6v11 */
    /* JADX WARN: Type inference failed for: r6v12 */
    /* JADX WARN: Type inference failed for: r6v13 */
    /* JADX WARN: Type inference failed for: r6v14 */
    /* JADX WARN: Type inference failed for: r6v2 */
    /* JADX WARN: Type inference failed for: r6v22 */
    /* JADX WARN: Type inference failed for: r6v23 */
    /* JADX WARN: Type inference failed for: r6v3, types: [int] */
    /* JADX WARN: Type inference failed for: r6v34 */
    /* JADX WARN: Type inference failed for: r6v35 */
    /* JADX WARN: Type inference failed for: r6v4 */
    /* JADX WARN: Type inference failed for: r6v5 */
    /* JADX WARN: Type inference failed for: r6v6, types: [int] */
    /* JADX WARN: Type inference failed for: r6v7, types: [int] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void handleResponse() throws BaseException {
        long j2;
        long j3;
        boolean z;
        char c2;
        IStreamReader iStreamReader;
        DownloadSetting downloadSetting;
        DownloadInfo downloadInfo;
        String str;
        IDownloadHttpConnection iDownloadHttpConnection;
        boolean z2;
        boolean z3;
        boolean z4;
        IDownloadHttpConnection iDownloadHttpConnection2;
        String str2;
        DownloadInfo downloadInfo2;
        DownloadSetting downloadSetting2;
        char c3;
        int i2;
        InputStream inputStream;
        long j4;
        long j5;
        long currentTimeMillis;
        long j6;
        long j7;
        if (isStoppedStatus() || this.downloadChunk == null) {
            return;
        }
        long contentLength = DownloadUtils.getContentLength(this.httpConnection);
        if (contentLength != 0) {
            int startOffset = this.downloadChunk.getStartOffset();
            long nanoTime = System.nanoTime();
            boolean z5 = this.isMonitorRw;
            boolean z6 = this.httpConnection instanceof AbsDownloadHttpConnection;
            int i3 = 1;
            try {
                try {
                    i2 = -1;
                    RandomAccessOutputStream createOutputStream = DownloadUtils.createOutputStream(this.downloadInfo, this.downloadInfo.getTempPath(), this.downloadInfo.getTempName(), this.setting.optInt(DownloadSettingKeys.FLUSH_BUFFER_SIZE_BYTE, -1));
                    this.outputStream = createOutputStream;
                    try {
                        try {
                            createOutputStream.seek(this.curOffset);
                            inputStream = this.httpConnection.getInputStream();
                        } catch (IOException e2) {
                            throw new BaseException((int) DownloadErrorCode.ERROR_RANDOM_ACCESS_SEEK_IO, e2);
                        }
                    } catch (BaseException e3) {
                        e = e3;
                        iStreamReader = null;
                        Logger.w(TAG, "handleResponse: BaseException e = " + e);
                        if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                        }
                        if (Logger.debug()) {
                        }
                        this.exception = e;
                        throw e;
                    } catch (Throwable th) {
                        th = th;
                        iStreamReader = null;
                        if (z6) {
                        }
                        Logger.w(TAG, "handleResponse: e = " + th);
                        if (!isStoppedStatus()) {
                        }
                    }
                } catch (Throwable th2) {
                    IDownloadHttpConnection iDownloadHttpConnection3 = this.httpConnection;
                    if (iDownloadHttpConnection3 != null) {
                        iDownloadHttpConnection3.end();
                    }
                    if (iStreamReader != null) {
                        iStreamReader.close();
                    }
                    try {
                        if (this.bugfixCancelThenUpdate) {
                            synchronized (this.callback) {
                                if (!this.canceled) {
                                    updateDownloadChunk(this.downloadCache);
                                    if (this.outputStream != null) {
                                        sync();
                                    }
                                }
                            }
                        } else {
                            updateDownloadChunk(this.downloadCache);
                            if (this.outputStream != null) {
                                sync();
                            }
                        }
                        Closeable[] closeableArr = new Closeable[startOffset];
                        closeableArr[c2] = this.outputStream;
                        DownloadUtils.safeClose(closeableArr);
                        this.debugTotalTimeNs = System.nanoTime() - nanoTime;
                        DownloadMonitorHelper.monitorDownloadIO(this.setting, this.downloadInfo, this.url, this.httpConnection, this.paused, this.canceled, this.exception, this.curOffset - this.handleStartOffset, this.debugTotalTimeNs, z, this.debugReadTimeNs, this.debugWriteTimeNs, this.debugSyncTimeNs, null);
                        throw th2;
                    } catch (Throwable th3) {
                        Closeable[] closeableArr2 = new Closeable[startOffset];
                        closeableArr2[c2] = this.outputStream;
                        DownloadUtils.safeClose(closeableArr2);
                        throw th3;
                    }
                }
            } catch (BaseException e4) {
                e = e4;
                z = z5;
            } catch (Throwable th4) {
                th = th4;
                j2 = contentLength;
                j3 = startOffset;
                z = z5;
            }
            if (inputStream != null) {
                this.downloadInfo.updateRealStartDownloadTime();
                iStreamReader = createStreamReader(inputStream);
                try {
                    this.downloadInfo.setIsRwConcurrent(this.rwConcurrent);
                    this.openLimitSpeed = this.downloadInfo.getOpenLimitSpeed();
                    long j8 = DownloadConstants.LIMIT_SPEED_EVERTS_ECOND;
                    j4 = DownloadConstants.LIMIT_INTERVSL;
                    j5 = j8 / (1000 / j4);
                    currentTimeMillis = System.currentTimeMillis();
                    j6 = 0;
                    j7 = 0;
                    startOffset = startOffset;
                } catch (BaseException e5) {
                    e = e5;
                    z = z5;
                } catch (Throwable th5) {
                    th = th5;
                    j2 = contentLength;
                    j3 = startOffset;
                    z = z5;
                }
                while (!isStoppedStatus()) {
                    z = z5;
                    if (z) {
                        try {
                            try {
                                j6 = System.nanoTime();
                            } catch (Throwable th6) {
                                th = th6;
                                j2 = contentLength;
                                j3 = startOffset;
                                if (z6) {
                                }
                                Logger.w(TAG, "handleResponse: e = " + th);
                                if (!isStoppedStatus()) {
                                }
                            }
                        } catch (BaseException e6) {
                            e = e6;
                            Logger.w(TAG, "handleResponse: BaseException e = " + e);
                            if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS) && isStoppedStatus()) {
                                IDownloadHttpConnection iDownloadHttpConnection4 = this.httpConnection;
                                if (iDownloadHttpConnection4 != null) {
                                    iDownloadHttpConnection4.end();
                                }
                                if (iStreamReader != null) {
                                    iStreamReader.close();
                                }
                                try {
                                    if (this.bugfixCancelThenUpdate) {
                                        synchronized (this.callback) {
                                            if (!this.canceled) {
                                                updateDownloadChunk(this.downloadCache);
                                                if (this.outputStream != null) {
                                                    sync();
                                                }
                                            }
                                        }
                                    } else {
                                        updateDownloadChunk(this.downloadCache);
                                        if (this.outputStream != null) {
                                            sync();
                                        }
                                    }
                                    Closeable[] closeableArr3 = new Closeable[startOffset];
                                    closeableArr3[c2] = this.outputStream;
                                    DownloadUtils.safeClose(closeableArr3);
                                    this.debugTotalTimeNs = System.nanoTime() - nanoTime;
                                    downloadSetting2 = this.setting;
                                    downloadInfo2 = this.downloadInfo;
                                    str2 = this.url;
                                    iDownloadHttpConnection2 = this.httpConnection;
                                    z4 = this.paused;
                                    z3 = this.canceled;
                                    DownloadMonitorHelper.monitorDownloadIO(downloadSetting2, downloadInfo2, str2, iDownloadHttpConnection2, z4, z3, this.exception, this.curOffset - this.handleStartOffset, this.debugTotalTimeNs, z, this.debugReadTimeNs, this.debugWriteTimeNs, this.debugSyncTimeNs, null);
                                    return;
                                } catch (Throwable th7) {
                                    Closeable[] closeableArr4 = new Closeable[startOffset];
                                    closeableArr4[c2] = this.outputStream;
                                    DownloadUtils.safeClose(closeableArr4);
                                    throw th7;
                                }
                            }
                            if (Logger.debug()) {
                                e.printStackTrace();
                            }
                            this.exception = e;
                            throw e;
                        }
                    }
                    Buffer read = iStreamReader.read();
                    if (z) {
                        this.debugReadTimeNs += System.nanoTime() - j6;
                    }
                    int i4 = read.size;
                    if (i4 == i2) {
                        j2 = contentLength;
                        j3 = startOffset;
                    } else {
                        if (this.downloadInfo.isIgnoreDataVerify()) {
                            j2 = contentLength;
                            j3 = startOffset;
                        } else {
                            j3 = startOffset;
                            try {
                                if (this.downloadChunkContentLen > this.curOffset - this.handleStartOffset) {
                                    j2 = contentLength;
                                    try {
                                        if (this.downloadChunkContentLen < (this.curOffset - this.handleStartOffset) + i4) {
                                            i4 = (int) (this.downloadChunkContentLen - (this.curOffset - this.handleStartOffset));
                                        }
                                    } catch (Throwable th8) {
                                        th = th8;
                                        if (z6) {
                                            ((AbsDownloadHttpConnection) this.httpConnection).onThrowable(th);
                                        }
                                        Logger.w(TAG, "handleResponse: e = " + th);
                                        if (!isStoppedStatus()) {
                                            IDownloadHttpConnection iDownloadHttpConnection5 = this.httpConnection;
                                            if (iDownloadHttpConnection5 != null) {
                                                iDownloadHttpConnection5.end();
                                            }
                                            if (iStreamReader != null) {
                                                iStreamReader.close();
                                            }
                                            try {
                                                if (this.bugfixCancelThenUpdate) {
                                                    synchronized (this.callback) {
                                                        if (!this.canceled) {
                                                            updateDownloadChunk(this.downloadCache);
                                                            if (this.outputStream != null) {
                                                                sync();
                                                            }
                                                        }
                                                    }
                                                } else {
                                                    updateDownloadChunk(this.downloadCache);
                                                    if (this.outputStream != null) {
                                                        sync();
                                                    }
                                                }
                                                Closeable[] closeableArr5 = new Closeable[startOffset];
                                                closeableArr5[c2] = this.outputStream;
                                                DownloadUtils.safeClose(closeableArr5);
                                                this.debugTotalTimeNs = System.nanoTime() - nanoTime;
                                                downloadSetting2 = this.setting;
                                                downloadInfo2 = this.downloadInfo;
                                                str2 = this.url;
                                                iDownloadHttpConnection2 = this.httpConnection;
                                                z4 = this.paused;
                                                z3 = this.canceled;
                                                DownloadMonitorHelper.monitorDownloadIO(downloadSetting2, downloadInfo2, str2, iDownloadHttpConnection2, z4, z3, this.exception, this.curOffset - this.handleStartOffset, this.debugTotalTimeNs, z, this.debugReadTimeNs, this.debugWriteTimeNs, this.debugSyncTimeNs, null);
                                                return;
                                            } catch (Throwable th9) {
                                                Closeable[] closeableArr6 = new Closeable[startOffset];
                                                closeableArr6[c2] = this.outputStream;
                                                DownloadUtils.safeClose(closeableArr6);
                                                throw th9;
                                            }
                                        }
                                        if (Logger.debug()) {
                                            th.printStackTrace();
                                        }
                                        try {
                                            DownloadUtils.parseException(th, "ResponseHandler");
                                            IDownloadHttpConnection iDownloadHttpConnection6 = this.httpConnection;
                                            if (iDownloadHttpConnection6 != null) {
                                                iDownloadHttpConnection6.end();
                                            }
                                            if (iStreamReader != null) {
                                                iStreamReader.close();
                                            }
                                            try {
                                                if (this.bugfixCancelThenUpdate) {
                                                    synchronized (this.callback) {
                                                        if (!this.canceled) {
                                                            updateDownloadChunk(this.downloadCache);
                                                            if (this.outputStream != null) {
                                                                sync();
                                                            }
                                                        }
                                                    }
                                                } else {
                                                    updateDownloadChunk(this.downloadCache);
                                                    if (this.outputStream != null) {
                                                        sync();
                                                    }
                                                }
                                                Closeable[] closeableArr7 = new Closeable[startOffset];
                                                closeableArr7[c2] = this.outputStream;
                                                DownloadUtils.safeClose(closeableArr7);
                                                this.debugTotalTimeNs = System.nanoTime() - nanoTime;
                                                downloadSetting = this.setting;
                                                downloadInfo = this.downloadInfo;
                                                str = this.url;
                                                iDownloadHttpConnection = this.httpConnection;
                                                z2 = this.paused;
                                                c3 = startOffset;
                                                DownloadMonitorHelper.monitorDownloadIO(downloadSetting, downloadInfo, str, iDownloadHttpConnection, z2, this.canceled, this.exception, this.curOffset - this.handleStartOffset, this.debugTotalTimeNs, z, this.debugReadTimeNs, this.debugWriteTimeNs, this.debugSyncTimeNs, null);
                                                if (this.downloadInfo.isIgnoreDataVerify()) {
                                                }
                                            } catch (Throwable th10) {
                                                Closeable[] closeableArr8 = new Closeable[startOffset];
                                                closeableArr8[c2] = this.outputStream;
                                                DownloadUtils.safeClose(closeableArr8);
                                                throw th10;
                                            }
                                        } catch (BaseException e7) {
                                            this.exception = e7;
                                            throw e7;
                                        }
                                    }
                                } else {
                                    j2 = contentLength;
                                }
                            } catch (Throwable th11) {
                                th = th11;
                                j2 = contentLength;
                            }
                        }
                        if (z) {
                            j6 = System.nanoTime();
                        }
                        this.outputStream.write(read.data, 0, i4);
                        if (z) {
                            this.debugWriteTimeNs += System.nanoTime() - j6;
                        }
                        iStreamReader.recycle(read);
                        long j9 = i4;
                        this.curOffset += j9;
                        j7 += j9;
                        synchronized (this.callback) {
                            try {
                                if (this.bugfixCancelThenUpdate) {
                                    if (!this.canceled) {
                                        boolean onProgress = this.callback.onProgress(j9);
                                        updateDownloadChunk(this.downloadCache);
                                        checkAndSync(onProgress);
                                    }
                                } else {
                                    boolean onProgress2 = this.callback.onProgress(j9);
                                    updateDownloadChunk(this.downloadCache);
                                    checkAndSync(onProgress2);
                                }
                            } finally {
                                th = th;
                                while (true) {
                                    try {
                                        break;
                                    } catch (Throwable th12) {
                                        th = th12;
                                    }
                                }
                            }
                        }
                        if (this.downloadInfo.isDownloadWithWifiValid()) {
                            if (this.downloadInfo.isPauseReserveWithWifiValid()) {
                                if (this.downloadInfo.isIgnoreDataVerify() || this.downloadChunkContentLen < 0 || this.downloadChunkContentLen > this.curOffset - this.handleStartOffset) {
                                    try {
                                        if (this.openLimitSpeed && j7 > j5) {
                                            long currentTimeMillis2 = System.currentTimeMillis() - currentTimeMillis;
                                            if (currentTimeMillis2 < j4) {
                                                try {
                                                    Thread.sleep(j4 - currentTimeMillis2);
                                                } catch (InterruptedException e8) {
                                                    e8.printStackTrace();
                                                }
                                            }
                                            currentTimeMillis = System.currentTimeMillis();
                                            j7 = 0;
                                        }
                                        z5 = z;
                                        contentLength = j2;
                                        startOffset = j3;
                                        i2 = -1;
                                        i3 = 1;
                                    } catch (BaseException e9) {
                                        e = e9;
                                        Logger.w(TAG, "handleResponse: BaseException e = " + e);
                                        if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                                        }
                                        if (Logger.debug()) {
                                        }
                                        this.exception = e;
                                        throw e;
                                    } catch (Throwable th13) {
                                        th = th13;
                                        if (z6) {
                                        }
                                        Logger.w(TAG, "handleResponse: e = " + th);
                                        if (!isStoppedStatus()) {
                                        }
                                    }
                                }
                            } else {
                                throw new DownloadPauseReserveWifiException();
                            }
                        } else {
                            throw new DownloadOnlyWifiException();
                        }
                    }
                    IDownloadHttpConnection iDownloadHttpConnection7 = this.httpConnection;
                    if (iDownloadHttpConnection7 != null) {
                        iDownloadHttpConnection7.end();
                    }
                    if (iStreamReader != null) {
                        iStreamReader.close();
                    }
                    try {
                        if (this.bugfixCancelThenUpdate) {
                            synchronized (this.callback) {
                                if (!this.canceled) {
                                    updateDownloadChunk(this.downloadCache);
                                    if (this.outputStream != null) {
                                        sync();
                                    }
                                }
                            }
                        } else {
                            updateDownloadChunk(this.downloadCache);
                            if (this.outputStream != null) {
                                sync();
                            }
                        }
                        DownloadUtils.safeClose(this.outputStream);
                        this.debugTotalTimeNs = System.nanoTime() - nanoTime;
                        downloadSetting = this.setting;
                        downloadInfo = this.downloadInfo;
                        str = this.url;
                        iDownloadHttpConnection = this.httpConnection;
                        c2 = 0;
                        z2 = this.paused;
                        c3 = 1;
                        DownloadMonitorHelper.monitorDownloadIO(downloadSetting, downloadInfo, str, iDownloadHttpConnection, z2, this.canceled, this.exception, this.curOffset - this.handleStartOffset, this.debugTotalTimeNs, z, this.debugReadTimeNs, this.debugWriteTimeNs, this.debugSyncTimeNs, null);
                        if (this.downloadInfo.isIgnoreDataVerify()) {
                            long j10 = this.curOffset - this.handleStartOffset;
                            if (j10 < 0 || this.downloadChunkContentLen < 0 || this.downloadChunkContentLen == j10) {
                                return;
                            }
                            Object[] objArr = new Object[7];
                            objArr[c2] = Long.valueOf(j10);
                            objArr[c3] = Long.valueOf(j2);
                            objArr[2] = Long.valueOf(this.downloadChunkContentLen);
                            objArr[3] = Long.valueOf(j3);
                            objArr[4] = Long.valueOf(this.endOffset);
                            objArr[5] = Long.valueOf(this.curOffset);
                            objArr[6] = Long.valueOf(this.handleStartOffset);
                            throw new BaseException((int) DownloadErrorCode.ERROR_RESPONSE_DATA_NOT_EQUALS, String.format("handle data length[%d] != content length[%d] downloadChunkContentLen[%d], range[%d, %d) , current offset[%d] , handle start from %d", objArr));
                        }
                        return;
                    } catch (Throwable th14) {
                        DownloadUtils.safeClose(this.outputStream);
                        throw th14;
                    }
                }
                IDownloadHttpConnection iDownloadHttpConnection8 = this.httpConnection;
                if (iDownloadHttpConnection8 != null) {
                    iDownloadHttpConnection8.end();
                }
                if (iStreamReader != null) {
                    iStreamReader.close();
                }
                try {
                    if (this.bugfixCancelThenUpdate) {
                        synchronized (this.callback) {
                            if (!this.canceled) {
                                updateDownloadChunk(this.downloadCache);
                                if (this.outputStream != null) {
                                    sync();
                                }
                            }
                        }
                    } else {
                        updateDownloadChunk(this.downloadCache);
                        if (this.outputStream != null) {
                            sync();
                        }
                    }
                    Closeable[] closeableArr9 = new Closeable[i3];
                    closeableArr9[0] = this.outputStream;
                    DownloadUtils.safeClose(closeableArr9);
                    this.debugTotalTimeNs = System.nanoTime() - nanoTime;
                    downloadSetting2 = this.setting;
                    downloadInfo2 = this.downloadInfo;
                    str2 = this.url;
                    iDownloadHttpConnection2 = this.httpConnection;
                    z4 = this.paused;
                    z = z5;
                    z3 = this.canceled;
                    DownloadMonitorHelper.monitorDownloadIO(downloadSetting2, downloadInfo2, str2, iDownloadHttpConnection2, z4, z3, this.exception, this.curOffset - this.handleStartOffset, this.debugTotalTimeNs, z, this.debugReadTimeNs, this.debugWriteTimeNs, this.debugSyncTimeNs, null);
                    return;
                } catch (Throwable th15) {
                    Closeable[] closeableArr10 = new Closeable[i3];
                    closeableArr10[0] = this.outputStream;
                    DownloadUtils.safeClose(closeableArr10);
                    throw th15;
                }
            }
            throw new BaseException((int) DownloadErrorCode.ERROR_NETWORK_NO_INPUT_STREAM, new IOException("inputStream is null"));
        }
        throw new DownloadRetryNeedlessException(1004, "the content-length is 0");
    }

    public void pause() {
        if (this.paused) {
            return;
        }
        this.paused = true;
        cancelConnection();
    }

    public void setChunkOffset(long j2, long j3, long j4) {
        this.curOffset = j2;
        this.handleStartOffset = j2;
        this.endOffset = j3;
        this.downloadChunkContentLen = j4;
    }

    public void setEndOffset(long j2, long j3) {
        this.endOffset = j2;
        this.downloadChunkContentLen = j3;
    }
}
