package com.ss.android.socialbase.downloader.segment;

import android.os.SystemClock;
import com.ss.android.socialbase.downloader.common.AppStatusManager;
import com.ss.android.socialbase.downloader.downloader.DownloadComponentManager;
import com.ss.android.socialbase.downloader.downloader.IDownloadCache;
import com.ss.android.socialbase.downloader.exception.BaseException;
import com.ss.android.socialbase.downloader.exception.DownloadOnlyWifiException;
import com.ss.android.socialbase.downloader.exception.DownloadPauseReserveWifiException;
import com.ss.android.socialbase.downloader.logger.Logger;
import com.ss.android.socialbase.downloader.model.DownloadInfo;
import com.ss.android.socialbase.downloader.monitor.DownloadMonitorHelper;
import com.ss.android.socialbase.downloader.network.DeviceBandwidthSampler;
import com.ss.android.socialbase.downloader.setting.DownloadSetting;
import com.ss.android.socialbase.downloader.setting.DownloadSettingKeys;
import com.ss.android.socialbase.downloader.thread.IDownloadRunnableCallback;
import com.ss.android.socialbase.downloader.utils.DownloadUtils;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class MultiSegmentWriter {
    public static final boolean DEBUG = false;
    public static final int MIN_CACHE_BYTES = 65536;
    public static final int MIN_CACHE_TIME_MS = 100;
    public static final int MIN_SYNC_STEP_BYTE = 65536;
    public static final long MIN_SYNC_TIME_MS = 500;
    public static final String TAG = "MultiSegmentWriter";
    public final IDownloadRunnableCallback callback;
    public final DownloadInfo downloadInfo;
    public BaseException exception;
    public final boolean hasSyncStrategy;
    public final boolean isMonitorRw;
    public final IBufferPool pool;
    public final DownloadSetting setting;
    public final long syncIntervalMsBg;
    public final long syncIntervalMsFg;
    public long syncTimeNs;
    public final List<SegmentOutput> outputs = new LinkedList();
    public final List<SegmentOutput> doneOutputs = new ArrayList();
    public volatile boolean threadDirty = false;
    public volatile boolean paused = false;
    public volatile boolean canceled = false;
    public volatile long lastSyncBytes = 0;
    public volatile long lastSyncTimestamp = 0;
    public final IDownloadCache downloadCache = DownloadComponentManager.getDownloadCache();
    public final AppStatusManager appStatusManager = AppStatusManager.getInstance();

    public MultiSegmentWriter(DownloadInfo downloadInfo, IDownloadRunnableCallback iDownloadRunnableCallback, IBufferPool iBufferPool) {
        this.downloadInfo = downloadInfo;
        this.callback = iDownloadRunnableCallback;
        this.pool = iBufferPool;
        DownloadSetting obtain = DownloadSetting.obtain(downloadInfo.getId());
        this.setting = obtain;
        boolean z = obtain.optInt(DownloadSettingKeys.SYNC_STRATEGY, 0) == 1;
        this.hasSyncStrategy = z;
        if (z) {
            this.syncIntervalMsFg = Math.max(this.setting.optInt(DownloadSettingKeys.SYNC_INTERVAL_MS_FG, 5000), 500L);
            this.syncIntervalMsBg = Math.max(this.setting.optInt(DownloadSettingKeys.SYNC_INTERVAL_MS_BG, 1000), 500L);
        } else {
            this.syncIntervalMsFg = 0L;
            this.syncIntervalMsBg = 0L;
        }
        this.isMonitorRw = this.setting.optInt(DownloadSettingKeys.MONITOR_RW) == 1;
    }

    private void checkAndSync(long j2, boolean z) throws IOException {
        long j3 = j2 - this.lastSyncTimestamp;
        if (this.hasSyncStrategy) {
            if (j3 > (this.appStatusManager.isAppForeground() ? this.syncIntervalMsFg : this.syncIntervalMsBg)) {
                flushAndSync();
                this.lastSyncTimestamp = j2;
                return;
            }
            return;
        }
        long curBytes = this.downloadInfo.getCurBytes() - this.lastSyncBytes;
        if (z || isNeedSync(curBytes, j3)) {
            flushAndSync();
            this.lastSyncTimestamp = j2;
        }
    }

    private void close(List<SegmentOutput> list) {
        for (SegmentOutput segmentOutput : list) {
            segmentOutput.close();
        }
    }

    private void flush(List<SegmentOutput> list) throws IOException {
        for (SegmentOutput segmentOutput : list) {
            segmentOutput.flush();
        }
    }

    private void flushAndSync() throws IOException {
        boolean z = this.isMonitorRw;
        long nanoTime = z ? System.nanoTime() : 0L;
        DownloadInfo downloadInfo = this.downloadInfo;
        IDownloadCache iDownloadCache = this.downloadCache;
        List<SegmentOutput> list = this.outputs;
        List<SegmentOutput> list2 = this.doneOutputs;
        Map<Long, Segment> segmentMap = iDownloadCache.getSegmentMap(downloadInfo.getId());
        if (segmentMap == null) {
            segmentMap = new HashMap<>(4);
        }
        synchronized (this) {
            flush(list);
            sync(list);
            updateSegmentToMap(list, segmentMap);
            if (list2.size() > 0) {
                close(list2);
                list.removeAll(list2);
                list2.clear();
            }
        }
        if (1 != 0) {
            downloadInfo.updateRealDownloadTime(true);
            iDownloadCache.updateSegments(downloadInfo.getId(), segmentMap);
            iDownloadCache.updateDownloadInfo(downloadInfo);
            this.lastSyncBytes = downloadInfo.getCurBytes();
        }
        if (z) {
            this.syncTimeNs += System.nanoTime() - nanoTime;
        }
    }

    private boolean isNeedSync(long j2, long j3) {
        return j2 > 65536 && j3 > 500;
    }

    private void outputDone(IOutput iOutput) {
        synchronized (this) {
            this.doneOutputs.add((SegmentOutput) iOutput);
        }
    }

    private void sync(List<SegmentOutput> list) throws IOException {
        for (SegmentOutput segmentOutput : list) {
            segmentOutput.sync();
        }
    }

    private void updateSegmentToMap(List<SegmentOutput> list, Map<Long, Segment> map) {
        for (SegmentOutput segmentOutput : list) {
            Segment segment = segmentOutput.getSegment();
            Segment segment2 = map.get(Long.valueOf(segment.getStartOffset()));
            if (segment2 == null) {
                map.put(Long.valueOf(segment.getStartOffset()), new Segment(segment));
            } else {
                segment2.setCurrentOffset(segment.getCurrentOffset());
                segment2.setEndOffset(segment.getEndOffset());
            }
        }
    }

    public void assignOutput(SegmentOutput segmentOutput) {
        synchronized (this) {
            this.outputs.add(segmentOutput);
        }
    }

    public void cancel() {
        this.canceled = true;
        this.threadDirty = true;
    }

    public long getLastSyncBytes() {
        return this.lastSyncBytes;
    }

    /* JADX WARN: Code restructure failed: missing block: B:208:0x02a4, code lost:
        r3.onProgress(r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x00b8, code lost:
        if (r13 <= 0) goto L267;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x00bb, code lost:
        r3.onProgress(r13);
     */
    /* JADX WARN: Removed duplicated region for block: B:160:0x01f4 A[Catch: all -> 0x03db, TryCatch #28 {all -> 0x03db, blocks: (B:158:0x01f0, B:160:0x01f4, B:163:0x01fa, B:165:0x0200, B:166:0x0203, B:167:0x0219, B:204:0x029e, B:205:0x02a0, B:244:0x0328, B:246:0x0332, B:248:0x0336, B:285:0x03b9, B:287:0x03bf, B:288:0x03c2, B:289:0x03da), top: B:363:0x0027, inners: #26 }] */
    /* JADX WARN: Removed duplicated region for block: B:165:0x0200 A[Catch: all -> 0x03db, TryCatch #28 {all -> 0x03db, blocks: (B:158:0x01f0, B:160:0x01f4, B:163:0x01fa, B:165:0x0200, B:166:0x0203, B:167:0x0219, B:204:0x029e, B:205:0x02a0, B:244:0x0328, B:246:0x0332, B:248:0x0336, B:285:0x03b9, B:287:0x03bf, B:288:0x03c2, B:289:0x03da), top: B:363:0x0027, inners: #26 }] */
    /* JADX WARN: Removed duplicated region for block: B:169:0x0220  */
    /* JADX WARN: Removed duplicated region for block: B:246:0x0332 A[Catch: all -> 0x03db, TryCatch #28 {all -> 0x03db, blocks: (B:158:0x01f0, B:160:0x01f4, B:163:0x01fa, B:165:0x0200, B:166:0x0203, B:167:0x0219, B:204:0x029e, B:205:0x02a0, B:244:0x0328, B:246:0x0332, B:248:0x0336, B:285:0x03b9, B:287:0x03bf, B:288:0x03c2, B:289:0x03da), top: B:363:0x0027, inners: #26 }] */
    /* JADX WARN: Removed duplicated region for block: B:287:0x03bf A[Catch: all -> 0x03db, TryCatch #28 {all -> 0x03db, blocks: (B:158:0x01f0, B:160:0x01f4, B:163:0x01fa, B:165:0x0200, B:166:0x0203, B:167:0x0219, B:204:0x029e, B:205:0x02a0, B:244:0x0328, B:246:0x0332, B:248:0x0336, B:285:0x03b9, B:287:0x03bf, B:288:0x03c2, B:289:0x03da), top: B:363:0x0027, inners: #26 }] */
    /* JADX WARN: Removed duplicated region for block: B:300:0x03ef  */
    /* JADX WARN: Removed duplicated region for block: B:339:0x022a A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:341:0x02ad A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:343:0x0365 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:345:0x00e3 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:368:0x0419 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:372:0x03f9 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:376:0x0249 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:378:0x02cc A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void loopAndWrite(IInput iInput) throws BaseException {
        DownloadInfo downloadInfo;
        long curBytes;
        long nanoTime;
        boolean z;
        boolean z2;
        long j2;
        long j3;
        long j4;
        long j5;
        Throwable th;
        int i2;
        Throwable th2;
        Throwable th3;
        Throwable th4;
        Throwable th5;
        Throwable th6;
        if (this.paused || this.canceled) {
            return;
        }
        DeviceBandwidthSampler.updateWifiStatus();
        this.exception = null;
        downloadInfo = this.downloadInfo;
        IDownloadRunnableCallback iDownloadRunnableCallback = this.callback;
        IBufferPool iBufferPool = this.pool;
        curBytes = downloadInfo.getCurBytes();
        nanoTime = System.nanoTime();
        z = this.isMonitorRw;
        long j6 = 0;
        z2 = true;
        int i3 = 0;
        boolean z3 = false;
        try {
            try {
                downloadInfo.updateRealStartDownloadTime();
                long j7 = 0;
                long j8 = 0;
                long j9 = 0;
                int i4 = 0;
                while (true) {
                    if (z) {
                        try {
                            j7 = System.nanoTime();
                        } catch (StreamClosedException e2) {
                            e = e2;
                            i3 = i4;
                            j5 = j8;
                            try {
                                this.exception = e;
                                throw e;
                            } catch (Throwable th7) {
                                th = th7;
                                j3 = j6;
                                j2 = j5;
                                if (i3 > 0) {
                                }
                                if (!this.canceled) {
                                }
                                th5 = null;
                                synchronized (this) {
                                }
                            }
                        } catch (BaseException e3) {
                            e = e3;
                            j3 = j6;
                            i2 = i4;
                            j4 = j8;
                            if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS) && (this.paused || this.canceled)) {
                                if (i2 > 0) {
                                    try {
                                        iDownloadRunnableCallback.onProgress(i2);
                                    } catch (Throwable unused) {
                                    }
                                }
                                if (!this.canceled) {
                                    try {
                                        flushAndSync();
                                    } catch (Throwable th8) {
                                        th4 = th8;
                                        Logger.w(TAG, "loopAndWrite: finally sync, e = " + th4);
                                        synchronized (this) {
                                            close(this.outputs);
                                            this.outputs.clear();
                                        }
                                        DownloadMonitorHelper.monitorDownloadIO(this.setting, downloadInfo, downloadInfo.getUrl(), null, this.paused, this.canceled, this.exception, downloadInfo.getCurBytes() - curBytes, System.nanoTime() - nanoTime, z, j3, j4, this.syncTimeNs, null);
                                        if (th4 != null) {
                                            if (!this.paused && !this.canceled && this.exception == null) {
                                                z2 = false;
                                            }
                                            if (z2) {
                                                return;
                                            }
                                            try {
                                                DownloadUtils.parseException(th4, "loopAndWrite_finally");
                                                return;
                                            } catch (BaseException e4) {
                                                this.exception = e4;
                                                throw e4;
                                            }
                                        }
                                        return;
                                    }
                                }
                                th4 = null;
                                synchronized (this) {
                                }
                            } else {
                                if (Logger.debug()) {
                                    e.printStackTrace();
                                }
                                Logger.w(TAG, "loopAndWrite:  BaseException e = " + e);
                                this.exception = e;
                                throw e;
                            }
                        } catch (Throwable th9) {
                            th = th9;
                            j3 = j6;
                            i3 = i4;
                            j2 = j8;
                            if (!this.paused && !this.canceled) {
                                if (Logger.debug()) {
                                    th.printStackTrace();
                                }
                                Logger.w(TAG, "loopAndWrite:  e = " + th);
                                try {
                                    DownloadUtils.parseException(th, "loopAndWrite");
                                    if (i3 > 0) {
                                        try {
                                            iDownloadRunnableCallback.onProgress(i3);
                                        } catch (Throwable unused2) {
                                        }
                                    }
                                    if (!this.canceled) {
                                        try {
                                            flushAndSync();
                                        } catch (Throwable th10) {
                                            th3 = th10;
                                            Logger.w(TAG, "loopAndWrite: finally sync, e = " + th3);
                                            synchronized (this) {
                                                close(this.outputs);
                                                this.outputs.clear();
                                            }
                                            DownloadMonitorHelper.monitorDownloadIO(this.setting, downloadInfo, downloadInfo.getUrl(), null, this.paused, this.canceled, this.exception, downloadInfo.getCurBytes() - curBytes, System.nanoTime() - nanoTime, z, j3, j2, this.syncTimeNs, null);
                                            if (th3 != null) {
                                                if (!this.paused && !this.canceled && this.exception == null) {
                                                    z2 = false;
                                                }
                                                if (z2) {
                                                    return;
                                                }
                                                try {
                                                    DownloadUtils.parseException(th3, "loopAndWrite_finally");
                                                    return;
                                                } catch (BaseException e5) {
                                                    this.exception = e5;
                                                    throw e5;
                                                }
                                            }
                                            return;
                                        }
                                    }
                                    th3 = null;
                                    synchronized (this) {
                                    }
                                } catch (BaseException e6) {
                                    this.exception = e6;
                                    throw e6;
                                }
                            }
                            if (!this.canceled) {
                                try {
                                    flushAndSync();
                                } catch (Throwable th11) {
                                    th2 = th11;
                                    Logger.w(TAG, "loopAndWrite: finally sync, e = " + th2);
                                    synchronized (this) {
                                        close(this.outputs);
                                        this.outputs.clear();
                                    }
                                    DownloadMonitorHelper.monitorDownloadIO(this.setting, downloadInfo, downloadInfo.getUrl(), null, this.paused, this.canceled, this.exception, downloadInfo.getCurBytes() - curBytes, System.nanoTime() - nanoTime, z, j3, j2, this.syncTimeNs, null);
                                    if (th2 != null) {
                                        if (!this.paused && !this.canceled && this.exception == null) {
                                            z2 = false;
                                        }
                                        if (z2) {
                                            return;
                                        }
                                        try {
                                            DownloadUtils.parseException(th2, "loopAndWrite_finally");
                                            return;
                                        } catch (BaseException e7) {
                                            this.exception = e7;
                                            throw e7;
                                        }
                                    }
                                    return;
                                }
                            }
                            th2 = null;
                            synchronized (this) {
                            }
                        }
                    }
                    try {
                        Buffer read = iInput.read();
                        if (z) {
                            j6 += System.nanoTime() - j7;
                        }
                        j3 = j6;
                        try {
                            int i5 = read.size;
                            if (i5 == -1) {
                                try {
                                    outputDone(read.output);
                                    iBufferPool.recycle(read);
                                    j6 = j3;
                                } catch (StreamClosedException e8) {
                                    e = e8;
                                    i3 = i4;
                                    j5 = j8;
                                    j6 = j3;
                                    this.exception = e;
                                    throw e;
                                } catch (BaseException e9) {
                                    e = e9;
                                    i2 = i4;
                                    j4 = j8;
                                    if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                                    }
                                    if (Logger.debug()) {
                                    }
                                    Logger.w(TAG, "loopAndWrite:  BaseException e = " + e);
                                    this.exception = e;
                                    throw e;
                                } catch (Throwable th12) {
                                    th = th12;
                                    i3 = i4;
                                    j2 = j8;
                                    if (!this.paused) {
                                        if (Logger.debug()) {
                                        }
                                        Logger.w(TAG, "loopAndWrite:  e = " + th);
                                        DownloadUtils.parseException(th, "loopAndWrite");
                                        if (i3 > 0) {
                                        }
                                        if (!this.canceled) {
                                        }
                                        th3 = null;
                                        synchronized (this) {
                                        }
                                    }
                                    if (!this.canceled) {
                                    }
                                    th2 = null;
                                    synchronized (this) {
                                    }
                                }
                            } else {
                                if (z) {
                                    j7 = System.nanoTime();
                                }
                                read.output.write(read);
                                if (z) {
                                    j8 += System.nanoTime() - j7;
                                }
                                j5 = j8;
                                try {
                                    iBufferPool.recycle(read);
                                    if (this.threadDirty) {
                                        if (this.paused) {
                                            break;
                                        }
                                        try {
                                            if (this.canceled) {
                                                break;
                                            }
                                            this.threadDirty = z3;
                                        } catch (StreamClosedException e10) {
                                            e = e10;
                                            i3 = i4;
                                            j6 = j3;
                                            this.exception = e;
                                            throw e;
                                        } catch (BaseException e11) {
                                            e = e11;
                                            i2 = i4;
                                            j4 = j5;
                                            if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                                            }
                                            if (Logger.debug()) {
                                            }
                                            Logger.w(TAG, "loopAndWrite:  BaseException e = " + e);
                                            this.exception = e;
                                            throw e;
                                        } catch (Throwable th13) {
                                            th = th13;
                                            i3 = i4;
                                            j2 = j5;
                                            if (!this.paused) {
                                            }
                                            if (!this.canceled) {
                                            }
                                            th2 = null;
                                            synchronized (this) {
                                            }
                                        }
                                    }
                                    i4 += i5;
                                    if (i4 >= 65536) {
                                        try {
                                            long uptimeMillis = SystemClock.uptimeMillis();
                                            if (uptimeMillis - j9 > 100) {
                                                long j10 = j7;
                                                try {
                                                    checkAndSync(uptimeMillis, iDownloadRunnableCallback.onProgress(i4));
                                                    if (!DeviceBandwidthSampler.isWifi) {
                                                        if (!downloadInfo.isOnlyWifi()) {
                                                            if (downloadInfo.isDownloadFromReserveWifi() && downloadInfo.isPauseReserveOnWifi()) {
                                                                throw new DownloadPauseReserveWifiException();
                                                            }
                                                        } else {
                                                            throw new DownloadOnlyWifiException();
                                                        }
                                                    }
                                                    j9 = uptimeMillis;
                                                    j6 = j3;
                                                    j8 = j5;
                                                    j7 = j10;
                                                    i4 = 0;
                                                    z3 = false;
                                                } catch (StreamClosedException e12) {
                                                    e = e12;
                                                    j6 = j3;
                                                    i3 = 0;
                                                    this.exception = e;
                                                    throw e;
                                                } catch (BaseException e13) {
                                                    e = e13;
                                                    j4 = j5;
                                                    i2 = 0;
                                                    if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                                                    }
                                                    if (Logger.debug()) {
                                                    }
                                                    Logger.w(TAG, "loopAndWrite:  BaseException e = " + e);
                                                    this.exception = e;
                                                    throw e;
                                                } catch (Throwable th14) {
                                                    th = th14;
                                                    j2 = j5;
                                                    i3 = 0;
                                                    if (!this.paused) {
                                                    }
                                                    if (!this.canceled) {
                                                    }
                                                    th2 = null;
                                                    synchronized (this) {
                                                    }
                                                }
                                            }
                                        } catch (StreamClosedException e14) {
                                            e = e14;
                                            i3 = i4;
                                            j6 = j3;
                                            this.exception = e;
                                            throw e;
                                        } catch (BaseException e15) {
                                            e = e15;
                                            i2 = i4;
                                            j4 = j5;
                                            if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                                            }
                                            if (Logger.debug()) {
                                            }
                                            Logger.w(TAG, "loopAndWrite:  BaseException e = " + e);
                                            this.exception = e;
                                            throw e;
                                        } catch (Throwable th15) {
                                            th = th15;
                                            i3 = i4;
                                            j2 = j5;
                                            if (!this.paused) {
                                            }
                                            if (!this.canceled) {
                                            }
                                            th2 = null;
                                            synchronized (this) {
                                            }
                                        }
                                    }
                                    j6 = j3;
                                    j8 = j5;
                                    j7 = j7;
                                    z3 = false;
                                } catch (StreamClosedException e16) {
                                    e = e16;
                                } catch (BaseException e17) {
                                    e = e17;
                                } catch (Throwable th16) {
                                    th = th16;
                                }
                            }
                        } catch (StreamClosedException e18) {
                            e = e18;
                            i3 = i4;
                            j5 = j8;
                        } catch (BaseException e19) {
                            e = e19;
                            i2 = i4;
                            j4 = j8;
                            if (!this.setting.optBugFix(DownloadSettingKeys.BugFix.IGNORE_BASE_EX_ON_STOP_STATUS)) {
                            }
                            if (Logger.debug()) {
                            }
                            Logger.w(TAG, "loopAndWrite:  BaseException e = " + e);
                            this.exception = e;
                            throw e;
                        } catch (Throwable th17) {
                            th = th17;
                            i3 = i4;
                            j2 = j8;
                            if (!this.paused) {
                            }
                            if (!this.canceled) {
                            }
                            th2 = null;
                            synchronized (this) {
                            }
                        }
                    } catch (StreamClosedException e20) {
                        e = e20;
                        i3 = i4;
                        j5 = j8;
                    } catch (BaseException e21) {
                        e = e21;
                        j3 = j6;
                    } catch (Throwable th18) {
                        th = th18;
                        j3 = j6;
                    }
                }
            } catch (Throwable th19) {
                th = th19;
                if (i3 > 0) {
                    try {
                        iDownloadRunnableCallback.onProgress(i3);
                    } catch (Throwable unused3) {
                    }
                }
                if (!this.canceled) {
                    try {
                        flushAndSync();
                    } catch (Throwable th20) {
                        Logger.w(TAG, "loopAndWrite: finally sync, e = " + th20);
                        th5 = th20;
                        synchronized (this) {
                        }
                    }
                }
                th5 = null;
                synchronized (this) {
                    close(this.outputs);
                    this.outputs.clear();
                }
                DownloadMonitorHelper.monitorDownloadIO(this.setting, downloadInfo, downloadInfo.getUrl(), null, this.paused, this.canceled, this.exception, downloadInfo.getCurBytes() - curBytes, System.nanoTime() - nanoTime, z, j3, j2, this.syncTimeNs, null);
                if (th5 != null) {
                    if (!this.paused && !this.canceled && this.exception == null) {
                        z2 = false;
                    }
                    if (!z2) {
                        try {
                            DownloadUtils.parseException(th5, "loopAndWrite_finally");
                        } catch (BaseException e22) {
                            this.exception = e22;
                            throw e22;
                        }
                    }
                }
                throw th;
            }
        } catch (StreamClosedException e23) {
            e = e23;
            j5 = 0;
        } catch (BaseException e24) {
            e = e24;
            j4 = 0;
            j3 = 0;
        } catch (Throwable th21) {
            th = th21;
            j2 = 0;
            j3 = 0;
        }
        if (!this.canceled) {
            try {
                flushAndSync();
            } catch (Throwable th22) {
                th6 = th22;
                Logger.w(TAG, "loopAndWrite: finally sync, e = " + th6);
                synchronized (this) {
                    close(this.outputs);
                    this.outputs.clear();
                }
                DownloadMonitorHelper.monitorDownloadIO(this.setting, downloadInfo, downloadInfo.getUrl(), null, this.paused, this.canceled, this.exception, downloadInfo.getCurBytes() - curBytes, System.nanoTime() - nanoTime, z, j3, j5, this.syncTimeNs, null);
                if (th6 != null) {
                    if (!this.paused && !this.canceled && this.exception == null) {
                        z2 = false;
                    }
                    if (z2) {
                        return;
                    }
                    try {
                        DownloadUtils.parseException(th6, "loopAndWrite_finally");
                        return;
                    } catch (BaseException e25) {
                        this.exception = e25;
                        throw e25;
                    }
                }
                return;
            }
        }
        th6 = null;
        synchronized (this) {
        }
    }

    public void pause() {
        this.paused = true;
        this.threadDirty = true;
    }
}
