package com.ss.android.socialbase.downloader.segment;

import android.os.Process;
import android.text.TextUtils;
import android.util.Log;
import androidx.appcompat.widget.TooltipCompatHandler;
import com.ss.android.socialbase.downloader.constants.DownloadErrorCode;
import com.ss.android.socialbase.downloader.downloader.DownloadComponentManager;
import com.ss.android.socialbase.downloader.exception.BaseException;
import com.ss.android.socialbase.downloader.exception.DownloadRetryNeedlessException;
import com.ss.android.socialbase.downloader.exception.RetryThrowable;
import com.ss.android.socialbase.downloader.logger.Logger;
import com.ss.android.socialbase.downloader.model.DownloadInfo;
import com.ss.android.socialbase.downloader.model.HttpHeader;
import com.ss.android.socialbase.downloader.model.HttpResponse;
import com.ss.android.socialbase.downloader.monitor.DownloadMonitorHelper;
import com.ss.android.socialbase.downloader.network.AbsDownloadHttpConnection;
import com.ss.android.socialbase.downloader.network.IDownloadHttpConnection;
import com.ss.android.socialbase.downloader.setting.DownloadSetting;
import com.ss.android.socialbase.downloader.setting.DownloadSettingKeys;
import com.ss.android.socialbase.downloader.utils.DownloadStenographer;
import com.ss.android.socialbase.downloader.utils.DownloadUtils;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class SegmentReader implements Runnable {
    public static final int SEGMENT_APPLY_RETRY_MAX_COUNT = 50;
    public static final int SWITCH_URL_MAX_COUNT = 30;
    public static final String TAG = "SegmentReader";
    public volatile boolean changeSegment;
    public volatile boolean closed;
    public volatile long connectEndTime;
    public volatile long connectStartTime;
    public String curHostIp;
    public String curHostRealIp;
    public int curRetryCount;
    public volatile Segment curSegment;
    public String curUrl;
    public final DownloadInfo downloadInfo;
    public volatile long endOffsetInConnection;
    public boolean exited;
    public boolean failed;
    public BaseException failedException;
    public Future future;
    public final ISegmentCallback host;
    public IDownloadHttpConnection httpConnection;
    public HttpResponse httpResponse;
    public boolean httpsToHttpRetryUsed;
    public long lastConnectStartTime;
    public final IBufferPool pool;
    public volatile long readBytes;
    public volatile long readEndTime;
    public volatile long readStartTime;
    public volatile boolean reconnect;
    public int retryCount;
    public int segmentApplyRetryTimes;
    public volatile long segmentNewEndOffset;
    public final DownloadSetting setting;
    public long startOffsetInConnection;
    public DownloadStenographer stenographer;
    public int switchUrlTimes;
    public Thread thread;
    public volatile boolean threadDirty;
    public final int threadIndex;
    public UrlRecord urlRecord;
    public final List<Segment> succeedSegments = new ArrayList();
    public volatile long curSegmentReadOffset = -1;

    public SegmentReader(DownloadInfo downloadInfo, SegmentDispatcher segmentDispatcher, IBufferPool iBufferPool, UrlRecord urlRecord, int i2) {
        this.downloadInfo = downloadInfo;
        this.host = segmentDispatcher;
        this.pool = iBufferPool;
        this.setting = DownloadSetting.obtain(downloadInfo.getId());
        this.urlRecord = urlRecord;
        this.threadIndex = i2;
    }

    private boolean checkCanUseHttpsToHttpRetry(BaseException baseException) {
        if (DownloadUtils.isHttpsError(baseException)) {
            String str = this.urlRecord.url;
            if (TextUtils.isEmpty(str) || !str.startsWith("https") || !this.downloadInfo.isNeedHttpsToHttpRetry() || this.httpsToHttpRetryUsed) {
                return false;
            }
            this.httpsToHttpRetryUsed = true;
            resetRetryTimes();
            return true;
        }
        return false;
    }

    private void closeConnection() {
        IDownloadHttpConnection iDownloadHttpConnection = this.httpConnection;
        if (iDownloadHttpConnection != null) {
            try {
                Logger.i(TAG, "closeConnection: thread = " + this.threadIndex);
                iDownloadHttpConnection.end();
                iDownloadHttpConnection.cancel();
            } catch (Throwable unused) {
            }
        }
    }

    private void createConnection(Segment segment) throws BaseException {
        String str;
        String str2;
        IDownloadHttpConnection downloadWithConnection;
        try {
            try {
                long currentTimeMillis = System.currentTimeMillis();
                this.connectEndTime = 0L;
                this.connectStartTime = currentTimeMillis;
                this.startOffsetInConnection = segment.getCurrentOffsetRead();
                this.endOffsetInConnection = segment.getEndOffset();
                if (this.endOffsetInConnection > 0 && this.startOffsetInConnection > this.endOffsetInConnection) {
                    throw new SegmentApplyException(6, "createConn, " + segment);
                }
                this.stenographer = new DownloadStenographer();
                List<HttpHeader> addRangeHeader = DownloadUtils.addRangeHeader(this.downloadInfo.getExtraHeaders(), this.downloadInfo.geteTag(), this.startOffsetInConnection, this.endOffsetInConnection);
                addRangeHeader.add(new HttpHeader("Segment-Index", String.valueOf(segment.getIndex())));
                addRangeHeader.add(new HttpHeader("Thread-Index", String.valueOf(this.threadIndex)));
                DownloadUtils.addThrottleNetSpeed(addRangeHeader, this.downloadInfo);
                DownloadUtils.addTTNetProtectTimeout(addRangeHeader, this.downloadInfo);
                str = this.urlRecord.url;
                if (this.httpsToHttpRetryUsed && !TextUtils.isEmpty(str) && str.startsWith("https")) {
                    str = str.replaceFirst("https", "http");
                }
                str2 = this.urlRecord.ip;
                Logger.i(TAG, "createConnectionBegin: url = " + str + ", ip = " + str2 + ", segment = " + segment + ", threadIndex = " + this.threadIndex);
                this.curUrl = str;
                this.curHostIp = str2;
                downloadWithConnection = DownloadComponentManager.downloadWithConnection(this.downloadInfo.isNeedDefaultHttpServiceBackUp(), this.downloadInfo.getMaxBytes(), str, str2, addRangeHeader, 0, currentTimeMillis - this.lastConnectStartTime > TooltipCompatHandler.HOVER_HIDE_TIMEOUT_SHORT_MS && this.setting.optInt(DownloadSettingKeys.MONITOR_DOWNLOAD_CONNECT) > 0, this.downloadInfo);
            } finally {
                this.connectEndTime = System.currentTimeMillis();
            }
        } catch (BaseException e2) {
            throw e2;
        } catch (Throwable th) {
            DownloadUtils.parseException(th, "createConn");
        }
        if (downloadWithConnection != null) {
            this.httpConnection = downloadWithConnection;
            this.httpResponse = new HttpResponse(str, downloadWithConnection);
            if (!this.closed) {
                if (downloadWithConnection instanceof AbsDownloadHttpConnection) {
                    this.curHostRealIp = ((AbsDownloadHttpConnection) downloadWithConnection).getHostIp();
                }
                Log.i(TAG, "createConnectionSuccess: url = " + str + ", ip = " + str2 + ", hostRealIp = " + this.curHostRealIp + ", threadIndex = " + this.threadIndex);
                return;
            }
            throw new StreamClosedException("createConn");
        }
        throw new BaseException((int) DownloadErrorCode.ERROR_NO_CONNECTION, new IOException("download can't continue, chunk connection is null"));
    }

    private void doConnect(Segment segment) throws BaseException, RetryThrowable {
        createConnection(segment);
        this.host.onSegmentConnected(this, segment, this.urlRecord, this.httpResponse);
        this.urlRecord.recordSucceed();
    }

    private boolean download(Segment segment) throws BaseException {
        initParams();
        while (true) {
            try {
                doConnect(segment);
                loopAndRead(segment);
                return true;
            } catch (SegmentApplyException e2) {
                this.failedException = e2;
                throw e2;
            } catch (Throwable th) {
                try {
                    Logger.e(TAG, "download: e = " + th + ", threadIndex = " + this.threadIndex + ", reconnect = " + this.reconnect + ", closed = " + this.closed);
                    if (this.closed) {
                        return false;
                    }
                    if (this.reconnect) {
                        this.reconnect = false;
                        Thread.interrupted();
                        if (this.changeSegment) {
                            this.changeSegment = false;
                            throw new SegmentApplyException(5, "download");
                        }
                    } else {
                        th.printStackTrace();
                        BaseException e3 = null;
                        if (th instanceof BaseException) {
                            e3 = th;
                        } else {
                            try {
                                DownloadUtils.parseException(th, "download");
                            } catch (BaseException e4) {
                                e3 = e4;
                            }
                        }
                        if (e3 == null || !handleFailedAndCheckRetry(segment, e3)) {
                            return false;
                        }
                    }
                } finally {
                    releaseDownload();
                }
            }
        }
        return false;
    }

    private boolean handleFailedAndCheckRetry(Segment segment, BaseException baseException) {
        Logger.e(TAG, "handleDownloadFailed:  e = " + baseException + ", curRetryCount = " + this.curRetryCount + ", retryCount = " + this.retryCount);
        this.failedException = baseException;
        this.urlRecord.recordFailed();
        this.host.onSegmentRetry(this, this.urlRecord, segment, baseException, this.curRetryCount, this.retryCount);
        int i2 = this.curRetryCount;
        if (i2 < this.retryCount) {
            this.curRetryCount = i2 + 1;
            return true;
        } else if (checkCanUseHttpsToHttpRetry(baseException)) {
            return true;
        } else {
            this.host.onSegmentFailed(this, this.urlRecord, segment, baseException);
            return false;
        }
    }

    private void initParams() {
        this.httpsToHttpRetryUsed = false;
        resetRetryTimes();
    }

    /* JADX WARN: Code restructure failed: missing block: B:100:0x01c4, code lost:
        r6 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x012e, code lost:
        r7 = r11 + 1;
        r11 = r13 - r7;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x0138, code lost:
        if (r11 <= 0) goto L171;
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x013a, code lost:
        com.ss.android.socialbase.downloader.logger.Logger.e(com.ss.android.socialbase.downloader.segment.SegmentReader.TAG, "loopAndRead: redundant = " + r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0150, code lost:
        r31.curSegmentReadOffset = r7;
     */
    /* JADX WARN: Code restructure failed: missing block: B:72:0x0153, code lost:
        r13 = r7;
        r11 = r11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:73:0x0157, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:0x0160, code lost:
        throw r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:82:0x0168, code lost:
        throw new com.ss.android.socialbase.downloader.segment.StreamClosedException("loopAndRead");
     */
    /* JADX WARN: Removed duplicated region for block: B:175:0x0316  */
    /* JADX WARN: Removed duplicated region for block: B:181:0x0327  */
    /* JADX WARN: Removed duplicated region for block: B:184:0x0334  */
    /* JADX WARN: Removed duplicated region for block: B:212:0x039d  */
    /* JADX WARN: Removed duplicated region for block: B:215:0x03aa  */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:78:0x015e -> B:79:0x015f). Please submit an issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void loopAndRead(Segment segment) throws BaseException {
        long j2;
        IOutput iOutput;
        InputStream inputStream;
        Buffer buffer;
        Buffer buffer2;
        Buffer buffer3;
        ISegmentCallback iSegmentCallback;
        long endOffset;
        int i2;
        long j3;
        long j4;
        Buffer buffer4;
        int i3;
        Buffer buffer5;
        int i4;
        Segment segment2 = segment;
        IBufferPool iBufferPool = this.pool;
        this.readStartTime = System.currentTimeMillis();
        long currentOffsetRead = segment.getCurrentOffsetRead();
        boolean z = false;
        try {
            try {
                inputStream = this.httpConnection.getInputStream();
                try {
                } catch (BaseException e2) {
                    e = e2;
                } catch (Throwable th) {
                    th = th;
                    j2 = currentOffsetRead;
                    iOutput = null;
                }
            } catch (Throwable th2) {
                DownloadUtils.safeClose(inputStream);
                if (iOutput != null) {
                    if (buffer == null) {
                        try {
                            buffer = iBufferPool.obtain();
                        } catch (Throwable unused) {
                            buffer2 = buffer;
                            if (buffer2 != null) {
                            }
                            this.readEndTime = System.currentTimeMillis();
                            if (j2 > currentOffsetRead) {
                            }
                            this.host.unApplySegment(this, segment2);
                            throw th2;
                        }
                    }
                    buffer.size = -1;
                    iOutput.write(buffer);
                    buffer2 = null;
                    if (buffer2 != null) {
                        iBufferPool.recycle(buffer2);
                    }
                    this.readEndTime = System.currentTimeMillis();
                    if (j2 > currentOffsetRead) {
                        DownloadMonitorHelper.monitorSegmentIO(this.setting, this.downloadInfo, this.curUrl, this.curHostIp, this.curHostRealIp, this.closed || this.reconnect, this.httpConnection, this.failedException, j2 - currentOffsetRead, TimeUnit.MILLISECONDS.toNanos(this.readEndTime - this.readStartTime));
                    }
                    this.host.unApplySegment(this, segment2);
                    throw th2;
                }
                buffer2 = buffer;
                if (buffer2 != null) {
                }
                this.readEndTime = System.currentTimeMillis();
                if (j2 > currentOffsetRead) {
                }
                this.host.unApplySegment(this, segment2);
                throw th2;
            }
        } catch (BaseException e3) {
            e = e3;
        } catch (Throwable th3) {
            th = th3;
            j2 = currentOffsetRead;
            iOutput = null;
            inputStream = null;
        }
        if (inputStream != null) {
            long contentLength = this.httpResponse.getContentLength();
            if (contentLength != 0) {
                buffer = probeFirstBuffer(iBufferPool, inputStream);
                try {
                } catch (BaseException e4) {
                    e = e4;
                } catch (Throwable th4) {
                    th = th4;
                    j2 = currentOffsetRead;
                    iOutput = null;
                }
                if (!this.reconnect && !this.closed) {
                    this.host.applySegment(this, segment2);
                    iOutput = this.host.createOutput(this, segment2);
                    try {
                        endOffset = segment.getEndOffset();
                        if (endOffset <= 0) {
                            endOffset = contentLength > 0 ? (contentLength + currentOffsetRead) - 1 : Long.MAX_VALUE;
                        }
                        i2 = buffer.size;
                        j3 = i2;
                        j2 = currentOffsetRead + j3;
                        try {
                        } catch (BaseException e5) {
                            e = e5;
                        } catch (Throwable th5) {
                            th = th5;
                        }
                    } catch (BaseException e6) {
                        e = e6;
                    } catch (Throwable th6) {
                        th = th6;
                        j2 = currentOffsetRead;
                    }
                    if (j2 > endOffset) {
                        long j5 = endOffset + 1;
                        if (j2 > j5 && (i4 = (int) (j3 - (j2 - j5))) > 0 && i4 < i2) {
                            buffer.size = i4;
                            j2 = j5;
                        }
                        this.curSegmentReadOffset = j2;
                        iOutput.write(buffer);
                        DownloadUtils.safeClose(inputStream);
                        if (iOutput != null) {
                            try {
                                Buffer obtain = iBufferPool.obtain();
                                try {
                                    obtain.size = -1;
                                    iOutput.write(obtain);
                                } catch (Throwable unused2) {
                                    buffer5 = obtain;
                                }
                            } catch (Throwable unused3) {
                            }
                        }
                        buffer5 = null;
                        if (buffer5 != null) {
                            iBufferPool.recycle(buffer5);
                        }
                        this.readEndTime = System.currentTimeMillis();
                        if (j2 > currentOffsetRead) {
                            DownloadMonitorHelper.monitorSegmentIO(this.setting, this.downloadInfo, this.curUrl, this.curHostIp, this.curHostRealIp, this.closed || this.reconnect, this.httpConnection, this.failedException, j2 - currentOffsetRead, TimeUnit.MILLISECONDS.toNanos(this.readEndTime - this.readStartTime));
                        }
                        this.host.unApplySegment(this, segment2);
                        return;
                    }
                    this.curSegmentReadOffset = j2;
                    iOutput.write(buffer);
                    long j6 = endOffset;
                    while (true) {
                        try {
                            if (this.threadDirty) {
                                try {
                                    synchronized (this) {
                                        this.threadDirty = z;
                                        if (this.reconnect || this.closed) {
                                            break;
                                        }
                                    }
                                    synchronized (this.host) {
                                        try {
                                            if (this.segmentNewEndOffset != 0) {
                                                Logger.i(TAG, "loopAndRead:  change readEnd = " + j6 + ", segmentNewEndOffset = " + this.segmentNewEndOffset + ", segment = " + segment2);
                                                j6 = refreshSegmentEndOffset();
                                                if (j2 > j6) {
                                                    break;
                                                }
                                            }
                                        } catch (Throwable th7) {
                                            th = th7;
                                        }
                                    }
                                } catch (BaseException e7) {
                                    e = e7;
                                    this.failedException = e;
                                    throw e;
                                } catch (Throwable th8) {
                                    th = th8;
                                    segment2 = segment;
                                    buffer = null;
                                    Logger.e(TAG, "loopAndRead: " + th + ",stack = " + Log.getStackTraceString(th));
                                    th.printStackTrace();
                                    try {
                                        DownloadUtils.parseException(th, "loopAndRead");
                                        DownloadUtils.safeClose(inputStream);
                                        if (iOutput != null) {
                                            if (buffer == null) {
                                                try {
                                                    buffer = iBufferPool.obtain();
                                                } catch (Throwable unused4) {
                                                    buffer3 = buffer;
                                                    if (buffer3 != null) {
                                                        iBufferPool.recycle(buffer3);
                                                    }
                                                    this.readEndTime = System.currentTimeMillis();
                                                    if (j2 > currentOffsetRead) {
                                                        DownloadMonitorHelper.monitorSegmentIO(this.setting, this.downloadInfo, this.curUrl, this.curHostIp, this.curHostRealIp, this.closed || this.reconnect, this.httpConnection, this.failedException, j2 - currentOffsetRead, TimeUnit.MILLISECONDS.toNanos(this.readEndTime - this.readStartTime));
                                                    }
                                                    iSegmentCallback = this.host;
                                                    iSegmentCallback.unApplySegment(this, segment2);
                                                    return;
                                                }
                                            }
                                            buffer.size = -1;
                                            iOutput.write(buffer);
                                            buffer3 = null;
                                            if (buffer3 != null) {
                                            }
                                            this.readEndTime = System.currentTimeMillis();
                                            if (j2 > currentOffsetRead) {
                                            }
                                            iSegmentCallback = this.host;
                                            iSegmentCallback.unApplySegment(this, segment2);
                                            return;
                                        }
                                        buffer3 = buffer;
                                        if (buffer3 != null) {
                                        }
                                        this.readEndTime = System.currentTimeMillis();
                                        if (j2 > currentOffsetRead) {
                                        }
                                        iSegmentCallback = this.host;
                                        iSegmentCallback.unApplySegment(this, segment2);
                                        return;
                                    } catch (BaseException e8) {
                                        this.failedException = e8;
                                        throw e8;
                                    }
                                }
                            }
                            buffer = iBufferPool.obtain();
                        } catch (BaseException e9) {
                            e = e9;
                        } catch (Throwable th9) {
                            th = th9;
                        }
                        try {
                            int read = inputStream.read(buffer.data);
                            buffer.size = read;
                            if (read == -1) {
                                iOutput.write(buffer);
                                j4 = 0;
                                iOutput = null;
                                break;
                            }
                            long j7 = read;
                            j2 += j7;
                            if (j2 > j6) {
                                long j8 = j6 + 1;
                                if (j2 > j8 && (i3 = (int) (j7 - (j2 - j8))) > 0 && i3 < read) {
                                    buffer.size = i3;
                                    j2 = j8;
                                }
                                this.curSegmentReadOffset = j2;
                                iOutput.write(buffer);
                                Logger.i(TAG, "loopAndRead: bytesRead = " + (j2 - currentOffsetRead) + ", url = " + this.urlRecord.url);
                            } else {
                                segment2 = segment;
                                this.curSegmentReadOffset = j2;
                                iOutput.write(buffer);
                                z = false;
                            }
                        } catch (BaseException e10) {
                            e = e10;
                            this.failedException = e;
                            throw e;
                        } catch (Throwable th10) {
                            th = th10;
                            segment2 = segment;
                            Logger.e(TAG, "loopAndRead: " + th + ",stack = " + Log.getStackTraceString(th));
                            th.printStackTrace();
                            DownloadUtils.parseException(th, "loopAndRead");
                            DownloadUtils.safeClose(inputStream);
                            if (iOutput != null) {
                            }
                            buffer3 = buffer;
                            if (buffer3 != null) {
                            }
                            this.readEndTime = System.currentTimeMillis();
                            if (j2 > currentOffsetRead) {
                            }
                            iSegmentCallback = this.host;
                            iSegmentCallback.unApplySegment(this, segment2);
                            return;
                        }
                    }
                    if (j6 > j4 && j6 != Long.MAX_VALUE && j2 <= j6) {
                        throw new BaseException((int) DownloadErrorCode.ERROR_RESPONSE_DATA_NOT_EQUALS, String.format("range[%d, %d] , but readCurrent[%d] , readStart[%d]", Long.valueOf(currentOffsetRead), Long.valueOf(j6), Long.valueOf(j2), Long.valueOf(currentOffsetRead)));
                    }
                    DownloadUtils.safeClose(inputStream);
                    if (iOutput != null) {
                        try {
                            Buffer obtain2 = iBufferPool.obtain();
                            try {
                                obtain2.size = -1;
                                iOutput.write(obtain2);
                            } catch (Throwable unused5) {
                                buffer4 = obtain2;
                            }
                        } catch (Throwable unused6) {
                        }
                    }
                    buffer4 = null;
                    if (buffer4 != null) {
                        iBufferPool.recycle(buffer4);
                    }
                    this.readEndTime = System.currentTimeMillis();
                    if (j2 > currentOffsetRead) {
                        DownloadMonitorHelper.monitorSegmentIO(this.setting, this.downloadInfo, this.curUrl, this.curHostIp, this.curHostRealIp, this.closed || this.reconnect, this.httpConnection, this.failedException, j2 - currentOffsetRead, TimeUnit.MILLISECONDS.toNanos(this.readEndTime - this.readStartTime));
                    }
                    iSegmentCallback = this.host;
                    segment2 = segment;
                    iSegmentCallback.unApplySegment(this, segment2);
                    return;
                }
                throw new StreamClosedException("probe");
            }
            throw new DownloadRetryNeedlessException(1004, "the content-length is 0, contentLength = " + contentLength);
        }
        throw new BaseException((int) DownloadErrorCode.ERROR_NETWORK_NO_INPUT_STREAM, new IOException("inputStream is null"));
    }

    private Buffer probeFirstBuffer(IBufferPool iBufferPool, InputStream inputStream) throws InterruptedException, BaseException, IOException {
        int i2;
        Buffer obtain = iBufferPool.obtain();
        try {
            i2 = inputStream.read(obtain.data);
        } catch (Throwable th) {
            th = th;
            i2 = -1;
        }
        try {
            if (i2 != -1) {
                obtain.size = i2;
                if (i2 == -1) {
                    iBufferPool.recycle(obtain);
                }
                return obtain;
            }
            throw new BaseException((int) DownloadErrorCode.ERROR_PROBE_FIRST_BUFFER, "probe");
        } catch (Throwable th2) {
            th = th2;
            if (i2 == -1) {
                iBufferPool.recycle(obtain);
            }
            throw th;
        }
    }

    private long refreshSegmentEndOffset() {
        long j2 = this.segmentNewEndOffset;
        this.segmentNewEndOffset = 0L;
        if (j2 <= 0) {
            return Long.MAX_VALUE;
        }
        return j2;
    }

    private void releaseDownload() {
        this.lastConnectStartTime = this.connectStartTime;
        this.connectStartTime = -1L;
        this.connectEndTime = -1L;
        this.readStartTime = -1L;
        this.readEndTime = -1L;
        closeConnection();
    }

    private void resetRetryTimes() {
        this.retryCount = this.urlRecord.isMainUrl ? this.downloadInfo.getRetryCount() : this.downloadInfo.getBackUpUrlRetryCount();
        this.curRetryCount = 0;
    }

    public boolean adjustSegmentEndOffset(long j2) {
        long j3 = this.endOffsetInConnection;
        if (j2 > 0 || j3 <= 0) {
            if (j2 <= j3 || j3 <= 0) {
                this.segmentNewEndOffset = j2;
                this.threadDirty = true;
                return true;
            }
            return false;
        }
        return false;
    }

    public void close() {
        Logger.i(TAG, "close: threadIndex = " + this.threadIndex);
        synchronized (this) {
            this.closed = true;
            this.threadDirty = true;
        }
        closeConnection();
        Future future = this.future;
        if (future != null) {
            this.future = null;
            try {
                future.cancel(true);
            } catch (Throwable th) {
                th.printStackTrace();
            }
        }
    }

    public int getCurRetryCount() {
        return this.curRetryCount;
    }

    public long getCurSegmentDownloadSpeed(long j2) {
        long j3 = this.readStartTime;
        if (j3 <= 0) {
            return -1L;
        }
        long j4 = j2 - j3;
        if (j4 <= 0) {
            return -1L;
        }
        long j5 = this.curSegmentReadOffset;
        long j6 = this.startOffsetInConnection;
        if (j6 < 0 || j5 < j6) {
            return 0L;
        }
        return (j5 - j6) / j4;
    }

    public long getCurSegmentReadOffset() {
        return this.curSegmentReadOffset;
    }

    public BaseException getFailedException() {
        return this.failedException;
    }

    public long getReadBytes() {
        long readingBytes;
        synchronized (this.host) {
            readingBytes = this.readBytes + getReadingBytes();
        }
        return readingBytes;
    }

    public long getReadingBytes() {
        synchronized (this.host) {
            long j2 = this.curSegmentReadOffset;
            long j3 = this.startOffsetInConnection;
            if (j3 < 0 || j2 <= j3) {
                return 0L;
            }
            return j2 - j3;
        }
    }

    public long getRecentDownloadSpeed(long j2, long j3) {
        DownloadStenographer downloadStenographer = this.stenographer;
        if (downloadStenographer == null) {
            return -1L;
        }
        return downloadStenographer.getRecentDownloadSpeed(j2, j3);
    }

    public int getRetryCount() {
        return this.retryCount;
    }

    public long getStartOffsetInConnection() {
        return this.startOffsetInConnection;
    }

    public boolean isExited() {
        return this.exited;
    }

    public boolean isFailed() {
        return this.failed;
    }

    public void markProgress(long j2) {
        long j3 = this.curSegmentReadOffset;
        DownloadStenographer downloadStenographer = this.stenographer;
        if (j3 < 0 || downloadStenographer == null) {
            return;
        }
        Log.i(TAG, "markProgress: curSegmentReadOffset = " + j3 + ", threadIndex = " + this.threadIndex);
        downloadStenographer.markProgress(j3, j2);
    }

    public void reconnect() {
        reconnect(false);
    }

    /* JADX WARN: Code restructure failed: missing block: B:18:0x007b, code lost:
        r6.curSegment = null;
        r2 = r6.host;
     */
    @Override // java.lang.Runnable
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void run() {
        Segment obtainSegment;
        ISegmentCallback iSegmentCallback;
        ISegmentCallback iSegmentCallback2;
        Process.setThreadPriority(10);
        try {
            this.thread = Thread.currentThread();
            this.host.onReaderRun(this);
            this.urlRecord.recordUse(this);
            while (true) {
                obtainSegment = this.host.obtainSegment(this, this.urlRecord);
                if (obtainSegment == null) {
                    Logger.i(TAG, "no more segment, thread_index = " + this.threadIndex);
                    break;
                }
                this.curSegment = obtainSegment;
                try {
                } catch (SegmentApplyException e2) {
                    Logger.e(TAG, "run: SegmentApplyException, e = " + e2);
                    if (this.segmentApplyRetryTimes >= 50) {
                        Logger.e(TAG, "segment apply failed " + this.segmentApplyRetryTimes + "times, thread_index = " + this.threadIndex);
                        this.curSegment = null;
                        iSegmentCallback = this.host;
                        break;
                    }
                    this.segmentApplyRetryTimes++;
                    this.curSegment = null;
                    iSegmentCallback2 = this.host;
                }
                if (download(obtainSegment)) {
                    this.succeedSegments.add(obtainSegment);
                    this.curSegment = null;
                    iSegmentCallback2 = this.host;
                    iSegmentCallback2.unObtainSegment(this, obtainSegment);
                } else if (!this.closed) {
                    Logger.e(TAG, "download segment failed, segment = " + obtainSegment + ", thread_index = " + this.threadIndex + ", failedException = " + this.failedException);
                    break;
                } else {
                    break;
                }
            }
            iSegmentCallback.unObtainSegment(this, obtainSegment);
            this.urlRecord.recordUnUse(this);
            this.host.onReaderExit(this);
        } catch (Throwable unused) {
        }
        this.thread = null;
    }

    public void setExited(boolean z) {
        this.exited = z;
    }

    public void setFailed(boolean z) {
        this.failed = z;
    }

    public void setFuture(Future future) {
        this.future = future;
    }

    public boolean switchUrlRecord(UrlRecord urlRecord) {
        int i2 = this.switchUrlTimes;
        if (i2 >= 30) {
            return false;
        }
        this.switchUrlTimes = i2 + 1;
        UrlRecord urlRecord2 = this.urlRecord;
        if (urlRecord2 != null) {
            urlRecord2.recordUnUse(this);
        }
        urlRecord.recordUse(this);
        this.urlRecord = urlRecord;
        resetRetryTimes();
        return true;
    }

    public void updateReadBytes() {
        UrlRecord urlRecord = this.urlRecord;
        try {
            synchronized (this.host) {
                long readingBytes = getReadingBytes();
                if (readingBytes > 0) {
                    this.readBytes += readingBytes;
                    urlRecord.increaseDownloadBytes(readingBytes);
                }
                this.curSegmentReadOffset = -1L;
            }
        } catch (Throwable unused) {
        }
    }

    public void reconnect(boolean z) {
        Logger.i(TAG, "reconnect: threadIndex = " + this.threadIndex);
        synchronized (this) {
            this.changeSegment = z;
            this.reconnect = true;
            this.threadDirty = true;
        }
        closeConnection();
        Thread thread = this.thread;
        if (thread != null) {
            try {
                Log.i(TAG, "reconnect: t.interrupt threadIndex = " + this.threadIndex);
                thread.interrupt();
            } catch (Throwable unused) {
            }
        }
    }
}
